==> cagibi-0.1.0.tar.bz2: cagibi-0.1.0/daemon/service.cpp <==
/*
    This file is part of the Cagibi library, part of the KDE project.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "service.h"
#include "service_p.h"


namespace Cagibi
{
bool Service::isKey( const QString& key ) { return ServicePrivate::isKey(key); }


Service::Service()
  : d( new ServicePrivate() )
{
}

Service::Service( ServicePrivate* _d )
  : d( _d )
{
}

Service::Service( const Service& other )
  : d( other.d )
{
}


const QString& Service::type() const { return d->type(); }
bool Service::isReady() const { return d->isReady(); }
const QString& Service::id() const { return d->id(); }
const QString& Service::descriptionUrl() const { return d->descriptionUrl(); }
const QString& Service::controlUrl() const { return d->controlUrl(); }
const QString& Service::eventSubUrl() const { return d->eventSubUrl(); }

Device Service::device() const { return d->device(); }

void Service::setProperty( const QString& key, const QString& value )
{
    d->setProperty( key, value );
}

void Service::setReady() { d->setReady(); }

Service& Service::operator=( const Service& other )
{
    d = other.d;
    return *this;
}

bool Service::operator==( const Service& other ) const
{
    return ( d == other.d );
}

Service::~Service()
{
}

}

==> cagibi_0.2.0.orig.tar.bz2: cagibi-0.2.0/daemon/service.cpp <==
/*
    This file is part of the Cagibi daemon.

    Copyright 2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "service.h"
#include "service_p.h"


namespace Cagibi
{
bool Service::isKey( const QString& key ) { return ServicePrivate::isKey(key); }


Service::Service()
  : d( new ServicePrivate() )
{
}

Service::Service( ServicePrivate* _d )
  : d( _d )
{
}

Service::Service( const Service& other )
  : d( other.d )
{
}


const QString& Service::type() const { return d->type(); }
bool Service::isReady() const { return d->isReady(); }
const QString& Service::id() const { return d->id(); }
const QString& Service::descriptionUrl() const { return d->descriptionUrl(); }
const QString& Service::controlUrl() const { return d->controlUrl(); }
const QString& Service::eventSubUrl() const { return d->eventSubUrl(); }

Device Service::device() const { return d->device(); }

void Service::setProperty( const QString& key, const QString& value )
{
    d->setProperty( key, value );
}

void Service::setReady() { d->setReady(); }

Service& Service::operator=( const Service& other )
{
    d = other.d;
    return *this;
}

bool Service::operator==( const Service& other ) const
{
    return ( d == other.d );
}

Service::~Service()
{
}

}
